@@ -1,11 +1,13 @@
-/* Copyright (c) 1991-2002 Doshita Lab. Speech Group, Kyoto University */
-/* Copyright (c) 2000-2002 Speech and Acoustics Processing Lab., NAIST */
-/*   All rights reserved   */
+/*
+ * Copyright (c) 1991-2003 Kyoto University
+ * Copyright (c) 2000-2003 NAIST
+ * All rights reserved
+ */
 
 /* m_fusion.c --- initialize all models, work area and parameters
                   to make up system */
 
-/* $Id: m_fusion.c,v 1.11 2003/01/06 16:10:39 ri Exp $ */
+/* $Id: m_fusion.c,v 1.14 2003/10/02 03:05:02 ri Exp $ */
 
 #include <julius.h>
 
@@ -108,11 +110,11 @@ initialize_dict()
   /* set {head,tail}_silwid */
   winfo->head_silwid = voca_lookup_wid(head_silname, winfo);
   if (winfo->head_silwid == WORD_INVALID) { /* not exist */
-    j_error("ERROR: head sil word \"%s\" not exist in voca", head_silname);
+    j_error("ERROR: head sil word \"%s\" not exist in voca\n", head_silname);
   }
   winfo->tail_silwid = voca_lookup_wid(tail_silname, winfo);
   if (winfo->tail_silwid == WORD_INVALID) { /* not exist */
-    j_error("ERROR: tail sil word \"%s\" not exist in voca", tail_silname);
+    j_error("ERROR: tail sil word \"%s\" not exist in voca\n", tail_silname);
   }
 #endif
   
@@ -147,20 +149,6 @@ initialize_ngram()
   make_voca_ref(ngram, winfo);
 }
 
-#ifdef CLASS_NGRAM
-static void
-initialize_class_ngram()
-{
-  /* allocate new */
-  class_ngram = ngram_info_new();
-  /* load LM */
-  init_ngram_bin(class_ngram, class_bingram_file);
-  /* map ordinal N-gram word ID to class ID */
-  make_class_ref(class_ngram, winfo);
-}  
-#endif
-
-
 
 #else  /* USE_DFA */
 
@@ -197,6 +185,7 @@ configure_param()
   /* select Gaussian pruning function */
   if (gprune_method == GPRUNE_SEL_UNDEF) {/* set default if not specified */
     if (hmminfo->is_tied_mixture) {
+      /* enabled by default for tied-mixture models */
 #ifdef GPRUNE_DEFAULT_SAFE
       gprune_method = GPRUNE_SEL_SAFE;
 #elif GPRUNE_DEFAULT_HEURISTIC
@@ -205,7 +194,7 @@ configure_param()
       gprune_method = GPRUNE_SEL_BEAM;
 #endif
     } else {
-      /* currently, pruning is available for only tied-mixture model */
+      /* disabled by default for non tied-mixture model */
       gprune_method = GPRUNE_SEL_NONE;
     }
   }
@@ -241,9 +230,6 @@ final_fusion()
   initialize_dict();
 #ifdef USE_NGRAM
   initialize_ngram();
-#ifdef CLASS_NGRAM
-  initialize_class_ngram();
-#endif
 #else
   initialize_dfa();
 #endif
