@@ -1,11 +1,13 @@
-/* Copyright (c) 1991-2002 Doshita Lab. Speech Group, Kyoto University */
-/* Copyright (c) 2000-2002 Speech and Acoustics Processing Lab., NAIST */
-/*   All rights reserved   */
+/*
+ * Copyright (c) 1991-2003 Kyoto University
+ * Copyright (c) 2000-2003 NAIST
+ * All rights reserved
+ */
 
 /* search_bestfirst_v1.c --- hypothesis handling and scoring functions
    for backscan algorithm */
 
-/* $Id: search_bestfirst_v1.c,v 1.7 2002/10/15 07:17:46 ri Exp $ */
+/* $Id: search_bestfirst_v1.c,v 1.9 2003/09/29 06:01:22 ri Exp $ */
 
 #include <julius.h>
 #ifndef PASS2_STRICT_IWCD
@@ -39,9 +41,18 @@ cpy_node(NODE *dst, NODE *src)
   dst->prev = src->prev;
   memcpy(dst->g, src->g, sizeof(LOGPROB) * peseqlen);
   memcpy(dst->seq, src->seq, sizeof(WORD_ID) * MAXSEQNUM);
-#ifdef WORD_ALIGNMENT
-  memcpy(dst->seq, src->seq, sizeof(short) * MAXSEQNUM);
-#endif  
+#ifdef CM_SEARCH
+#ifdef CM_MULTIPLE_ALPHA
+  {
+    int w;
+    for(w=0;w<src->seqnum;w++) {
+      memcpy(dst->cmscore[w], src->cmscore[w], sizeof(LOGPROB) * cm_alpha_num);
+    }
+  }     
+#else
+  memcpy(dst->cmscore, src->cmscore, sizeof(LOGPROB) * MAXSEQNUM);
+#endif
+#endif /* CM_SEARCH */
   dst->seqnum = src->seqnum;
   dst->score = src->score;
   dst->bestt = src->bestt;
@@ -632,6 +643,13 @@ next_word(NODE *now, NODE *new,	NEXTWORD *nword, HTK_Param *param, BACKTRELLIS *
   /* inherit and update word sequence, DFA state and total LM score */
   for (i=0;i< now->seqnum;i++){	
     new->seq[i] = now->seq[i];
+#ifdef CM_SEARCH
+#ifdef CM_MULTIPLE_ALPHA
+    memcpy(new->cmscore[i], now->cmscore[i], sizeof(LOGPROB) * cm_alpha_num);
+#else
+    new->cmscore[i] = now->cmscore[i];
+#endif
+#endif /* CM_SEARCH */
   }
   new->seq[i] = word;
   new->seqnum = now->seqnum+1;
@@ -795,6 +813,7 @@ next_word(NODE *now, NODE *new,	NEXTWORD *nword, HTK_Param *param, BACKTRELLIS *
       new->score = totalscore;
       new->bestt = t;
       new->estimated_next_t = tre->begintime - 1;
+      new->tre = tre;
     }
   }
   /* 2. search backward */
@@ -811,6 +830,7 @@ next_word(NODE *now, NODE *new,	NEXTWORD *nword, HTK_Param *param, BACKTRELLIS *
       new->score = totalscore;
       new->bestt = t;
       new->estimated_next_t = tre->begintime - 1;
+      new->tre = tre;
     }
   }
 
@@ -893,6 +913,7 @@ start_word(
       
       new->score = new->g[peseqlen-1] + tre->backscore + tmpp;
       new->estimated_next_t = tre->begintime - 1;
+      new->tre = tre;
       break;
     }
   }
