@@ -1,10 +1,12 @@
-/* Copyright (c) 1991-2002 Doshita Lab. Speech Group, Kyoto University */
-/* Copyright (c) 2000-2002 Speech and Acoustics Processing Lab., NAIST */
-/*   All rights reserved   */
+/*
+ * Copyright (c) 1991-2003 Kyoto University
+ * Copyright (c) 2000-2003 NAIST
+ * All rights reserved
+ */
 
 /* speech.h --- low-level adin */
 
-/* $Id: speech.h,v 1.6 2002/09/11 22:01:50 ri Exp $ */
+/* $Id: speech.h,v 1.8 2003/09/29 06:01:22 ri Exp $ */
 
 /* defines for analisys/classification server */
 /* speech input limitation */
@@ -31,6 +33,11 @@ enum{SP_RESULT_TTY, SP_RESULT_MSOCK}; /* result output device*/
 /* for anlz/wrsamp.c */
 int wrsamp(int fd, SP16 *buf, int len);
 
+/* for anlz/wrwav.c */
+FILE *wrwav_open(char *filename, int sfreq);
+boolean wrwav_data(FILE *fp, SP16 *buf, int len);
+boolean wrwav_close(FILE *fp);
+
 /* for an;z/strip.c */
 int strip_zero(SP16 a[], int len);
 
