@@ -1,10 +1,12 @@
-/* Copyright (c) 1991-2002 Doshita Lab. Speech Group, Kyoto University */
-/* Copyright (c) 2000-2002 Speech and Acoustics Processing Lab., NAIST */
-/*   All rights reserved   */
+/*
+ * Copyright (c) 1991-2003 Kyoto University
+ * Copyright (c) 2000-2003 NAIST
+ * All rights reserved
+ */
 
 /* put_htkdata_data.c --- output hmm/param info to stdout (for debug) */
 
-/* $Id: put_htkdata_info.c,v 1.2 2002/09/11 22:01:50 ri Exp $ */
+/* $Id: put_htkdata_info.c,v 1.4 2003/09/29 06:01:23 ri Exp $ */
 
 #include <sent/stddefs.h>
 #include <sent/htk_hmm.h>
@@ -209,7 +211,7 @@ void
 print_hmmdef_info(HTK_HMM_INFO *hmminfo)
 {
   j_printf("HMM Info:\n");
-  j_printf(" %d models, %d states, %d mixtures are defined\n",
+  j_printf("    %d models, %d states, %d mixtures are defined\n",
 	   hmminfo->totalhmmnum, hmminfo->totalstatenum, hmminfo->totalmixnum);
   j_printf("\t      model type = ");
   if (hmminfo->is_tied_mixture) j_printf("tied-mixture, ");
@@ -219,7 +221,7 @@ print_hmmdef_info(HTK_HMM_INFO *hmminfo)
     j_printf("\t    codebook num = %d\n", hmminfo->codebooknum);
     j_printf("\tmax codebook size= %d\n", hmminfo->maxcodebooksize);
   }
-  j_printf(" training parameter type = %s\n",param_code2str(buf, hmminfo->opt.param_type, FALSE));
+  j_printf("      training parameter = %s\n",param_code2str(buf, hmminfo->opt.param_type, FALSE));
   j_printf("\t   vector length = %d\n", hmminfo->opt.vec_size);
   j_printf("\tcov. matrix type = %s\n", get_cov_str(hmminfo->opt.cov_type));
   j_printf("\t   duration type = %s\n", get_dur_str(hmminfo->opt.dur_type));
