@@ -1,10 +1,12 @@
-/* Copyright (c) 1991-2002 Doshita Lab. Speech Group, Kyoto University */
-/* Copyright (c) 2000-2002 Speech and Acoustics Processing Lab., NAIST */
-/*   All rights reserved   */
+/*
+ * Copyright (c) 1991-2003 Kyoto University
+ * Copyright (c) 2000-2003 NAIST
+ * All rights reserved
+ */
 
 /* ngram_read_bin.c --- read in n-gram data in bingram (binary format for Julius) */
 
-/* $Id: ngram_read_bin.c,v 1.5 2002/09/11 22:01:50 ri Exp $ */
+/* $Id: ngram_read_bin.c,v 1.7 2003/09/29 06:01:23 ri Exp $ */
 
 #include <sent/stddefs.h>
 #include <sent/ngram2.h>
@@ -29,14 +31,26 @@ rdn(FILE *fp, void *buf, size_t unitbyte, int unitnum)
 static void
 check_header(FILE *fp)
 {
-  char buf[512];
+  char buf[512], *p;
   rdn(fp, buf, 1, 512);
-
-  if (! strnmatch(buf, BINGRAM_IDSTR, strlen(BINGRAM_IDSTR))) {
+  
+  p = buf;
+  if (! strnmatch(p, BINGRAM_IDSTR, strlen(BINGRAM_IDSTR))) {
     /* not a v3 bingram file */
     j_printerr("Error: invalid header, you probably use old bingram\n");
     j_printerr("Error: if so, please re-make with newer mkbingram that comes with Julius-2.0 or later\n");
   }
+  p += strlen(BINGRAM_IDSTR) + 1;
+  if (strnmatch(p, BINGRAM_SIZESTR_HEAD, strlen(BINGRAM_SIZESTR_HEAD))) {
+    /* word size check (for bingram build by mkbingram 3.3p5 and later */
+    p += strlen(BINGRAM_SIZESTR_HEAD);
+    if (! strnmatch(p, BINGRAM_SIZESTR_BODY, strlen(BINGRAM_SIZESTR_BODY))) {
+      /* word size does not match (int / short) */
+      /*** it should be converted, but just terminate here... ***/
+      j_error("Error: word size does not match in bingram\n");
+    }
+  } /* if no BINGRAM_SIZESTR_HEAD found, just pass it */
+    
   /*j_printf("%s",buf);*/
 }
 
